@@ -117,7 +117,14 @@ Mainmenu::Mainmenu(){
     }
 
     void Mainmenu::readDesktopFileInformation(Entry *entry){
-        QFile file("/usr/share/applications/hildon/"+entry->getDesktopName()+".desktop");
+        QFile file;
+
+        file.setFileName("/usr/share/applications/hildon/"+entry->getDesktopName()+".desktop");
+
+        if ( file.exists() == 0 ){
+            file.setFileName("/home/user/.local/share/applications/hildon/"+entry->getDesktopName()+".desktop");
+        }
+        
         QString line("");
         bool name = false;
         bool icon = false;
@@ -206,8 +213,8 @@ Mainmenu::Mainmenu(){
     void Mainmenu::showAbout()
     {
         QMessageBox::about(this, tr("About Catorise PLUS"),
-                tr("<p><b>Catorise PLUS</b> is a graphical user interface for catorise<br />"
-                   "It is originally based on Catorise GUI by Recep Karadas (<a href=\"http://www.reckdesign.de\" >Reckdesign</a>)"
+                tr("<p><b>Catorise PLUS</b> is a extended version from catorise with a graphical user interface.<br />"
+                   "It is originally based on catorise by <a href=\"http://www.bleb.org/\">Andrew Flegg</a> and Catorise GUI by Recep Karadas (<a href=\"http://www.reckdesign.de\" >Reckdesign</a>)"
                    "</p>"));
     }
 
